<template>
  <div>
    <div v-if="logList && logList.length > 0">
      <div class="log-warp" v-for="log in logList" :key="'log' + log.id">
        <div class="log" v-if="log.eventType === 'FINISHED'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag op">完成</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'REJECT'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag reject">驳回</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag reject">驳回原因</span>
            ：
            <span class="tag">{{log.eventDataObj.reason}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'HANGUP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag reject">挂起</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag reject">挂起原因</span>
            ：
            <span class="tag">{{log.eventDataObj.reason}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'CANCEL_HANGUP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag reject">取消挂起</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'DELEGATE'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            将任务
            <span class="tag taskName">{{log.taskName}}</span>
            <span class="tag op">转办</span>
            给了
            <span class="tag">{{log.eventDataObj.afterHandlerNames.join('、')}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'JUMP'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag jump">跳过</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag jump">跳过说明</span>
            ：
            <span class="tag">{{log.eventDataObj.desc}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'SUPERVISE'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            <span class="tag db">督办</span>
            了任务
            <span class="tag taskName">{{log.taskName}}</span>
            ，
            <span class="tag db">督办信息</span>
            ：
            <span class="tag">{{log.eventDataObj.content}}</span>
          </div>
        </div>
        <div class="log" v-else-if="log.eventType === 'TEAM_WORK'">
          <div>
            <span class="tag name">{{log.nickName}}</span>
            于
            <span class="tag time">{{log.gmtCreate}}</span>
            邀请了谁谁谁
            <span class="tag op">协同办理</span>
            <span class="tag taskName">{{log.taskName}}</span>
          </div>
        </div>
      </div>
    </div>
    <div v-else style="display: flex;justify-content: center;align-items: center;height: 500px">
      <el-empty :image="emptyImage" description="未查询到日志信息"></el-empty>
    </div>
  </div>
</template>

<script>
export default {
  name: "LogView",
  props: {
    logList: {
      require: true,
      type: Array
    }
  },
  data() {
    return {
      emptyImage: require('@/assets/nodata.png')
    }
  }
}
</script>

<style scoped>
.log-warp {
  font-size: 16px;
}
.log {
  width: 100%;
  margin-bottom: 15px;
  overflow-wrap: break-word;
  background-color: #E4E7ED;
  padding: 5px 5px;
}
.tag {
  margin: 0 5px;
}
.name {
  color: #E6A23C;
}
.time {
  color: #909399;
}
.taskName {
  color: #409EFF;
}
.op {
  color: #67C23A;
}
.reject, .db, .jump {
  color: #F56C6C;
}
</style>
